@@ -96,6 +96,7 @@ class Application:
         self.progress_bar.set_visible(False)
 
         self.needs_restart = False
+        self.needs_broadcom_reload = False
         self.live_mode = False
 
         self.show_page("refresh_page")
@@ -253,6 +254,9 @@ class Application:
                 self.button_driver_apply.set_sensitive(bool(self.driver_changes))
 
         if installs is None or len(installs) == 0 or errors:
+            if self.needs_broadcom_reload:
+                print("Reloading Broadcom modules")
+                subprocess.Popen(['mintdrivers-load-broadcom-modules'])
             self.needs_restart = (not errors)
             self.progress_bar.set_visible(False)
             self.apt_cache = apt.Cache()
@@ -291,6 +295,8 @@ class Application:
                             removals.append(self.get_package_id(dep_pkg.installed))
             else:
                 installs.append(self.get_package_id(pkg.candidate))
+                if pkg.shortname == "broadcom-sta-dkms":
+                    self.needs_broadcom_reload = True
 
         self.cancellable = Gio.Cancellable()
         try:
@@ -498,7 +504,7 @@ class Application:
                 description_line3 = "<small>%s</small>" % summary
                 if driver_status == 'recommended':
                     description_line1 = "%s <b><small><span foreground='#58822B'>(%s)</span></small></b>" % (description_line1, _("recommended"))
-                if current_driver['free'] and pkg.shortname != "bcmwl-kernel-source" and (not pkg.shortname.startswith("nvidia-")):
+                if current_driver['free'] and pkg.shortname != "broadcom-sta-dkms" and (not pkg.shortname.startswith("nvidia-")):
                     description_line1 = "%s <b><small><span foreground='#717bbd'>(%s)</span></small></b>" % (description_line1, _("open-source"))
                 if pkg.shortname.startswith("firmware-b43"):
                     # B43 requires a connection to the Internet
@@ -718,7 +724,7 @@ class Application:
         for device in self.devices:
             for pkg_name in self.devices[device]['drivers']:
                 pkg = self.apt_cache[pkg_name]
-                if (not self.devices[device]['drivers'][pkg_name]['free'] or pkg_name == "bcmwl-kernel-source") and pkg.is_installed:
+                if (not self.devices[device]['drivers'][pkg_name]['free'] or pkg_name == "broadcom-sta-dkms") and pkg.is_installed:
                     self.nonfree_drivers = self.nonfree_drivers + 1
 
         if self.nonfree_drivers > 0:
